@@ -9,19 +9,17 @@
 #define OFF 0
 #endif
 
-#define OBS_VERSION "27.1.3-1"
+#define OBS_VERSION "28.0.3-2"
+#define OBS_VERSION_CANONICAL "28.0.3"
 #define OBS_DATA_PATH "share/obs"
 #define OBS_INSTALL_PREFIX "/usr/"
 #define OBS_PLUGIN_DESTINATION "lib/obs-plugins"
-#define OBS_RELATIVE_PREFIX "../"
-#define OBS_UNIX_STRUCTURE 1
-#define HAVE_DBUS 1
-#define HAVE_PULSEAUDIO 1
-#define USE_XINPUT 1
-#define LIBOBS_IMAGEMAGICK_DIR_STYLE_6L 6
-#define LIBOBS_IMAGEMAGICK_DIR_STYLE_7GE 7
-#define LIBOBS_IMAGEMAGICK_DIR_STYLE 
+#define OBS_QT_VERSION 6
 
+/* #undef LINUX_PORTABLE */
+#define GIO_FOUND
+#define PULSEAUDIO_FOUND
+#define XCB_XINPUT_FOUND
 #define ENABLE_WAYLAND
 
 /* NOTE: Release candidate version numbers internally are always the previous
@@ -40,3 +38,13 @@
 	                      OBS_RELEASE_CANDIDATE_MINOR, \
 	                      OBS_RELEASE_CANDIDATE_PATCH)
 #define OBS_RELEASE_CANDIDATE 0
+
+/* Same thing for beta builds */
+#define OBS_BETA_MAJOR 0
+#define OBS_BETA_MINOR 0
+#define OBS_BETA_PATCH 0
+#define OBS_BETA_VER \
+	MAKE_SEMANTIC_VERSION(OBS_BETA_MAJOR, \
+	                      OBS_BETA_MINOR, \
+	                      OBS_BETA_PATCH)
+#define OBS_BETA 0
